@@ -5,24 +5,24 @@ context('encodefrom')
 ## -----------------------------------------------------------------------------
 
 ## set up data
-df <- tibble::data_frame(state = c('Texas','Louisiana','Massachusetts',
-                                   'Florida','Oregon','Montana',
-                                   'Washington','Arkansas','Tennessee',
-                                   'Mississippi','Utah','Alabama',
-                                   'Kentucky','Maine','Michigan',
-                                   'California','Illinois','Delaware',
-                                   'Idaho','North Carolina','Nebraska',
-                                   'Maryland','Virginia','Pennsylvania',
-                                   'Rhode Island','South Carolina','Iowa',
-                                   'New Hampshire','Kansas','Nevada',
-                                   'South Dakota','Colorado','Arizona',
-                                   'Alaska','New York','Oklahoma',
-                                   'Wisconsin','Wyoming','Connecticut',
-                                   'Missouri','Minnesota','Ohio',
-                                   'Georgia','New Jersey','Vermont',
-                                   'District of Columbia','North Dakota',
-                                   'New Mexico','West Virginia','Indiana',
-                                   'Hawaii'),
+df <- tibble::tibble(state = c('Texas','Louisiana','Massachusetts',
+                               'Florida','Oregon','Montana',
+                               'Washington','Arkansas','Tennessee',
+                               'Mississippi','Utah','Alabama',
+                               'Kentucky','Maine','Michigan',
+                               'California','Illinois','Delaware',
+                               'Idaho','North Carolina','Nebraska',
+                               'Maryland','Virginia','Pennsylvania',
+                               'Rhode Island','South Carolina','Iowa',
+                               'New Hampshire','Kansas','Nevada',
+                               'South Dakota','Colorado','Arizona',
+                               'Alaska','New York','Oklahoma',
+                               'Wisconsin','Wyoming','Connecticut',
+                               'Missouri','Minnesota','Ohio',
+                               'Georgia','New Jersey','Vermont',
+                               'District of Columbia','North Dakota',
+                               'New Mexico','West Virginia','Indiana',
+                               'Hawaii'),
                          y = seq(1:51))
 
 crosswalk_file <- system.file('extdata', 'stcrosswalk.rda',
